searchData={"items":[{"type":"module","title":"Cowrie","doc":"`Cowrie` helps you print beautiful and consistent Terminal output to the Shell\nusing familiar functions inspired by HTML.\n\nThe output of each function can be styled via configuration (see the page on\nconfiguration) or by overriding any configured styles by passing relevant\noptions as the second argument. This is analogous to cascading style sheets (CSS).","ref":"Cowrie.html"},{"type":"function","title":"Cowrie.alert/2","doc":"Prints an alert box of the specified type to STDOUT\n(think [Bootstrap alert boxes](https://getbootstrap.com/docs/4.0/components/alerts/)).\n\nOptions:\n- `:type` indicates the type of alert, one of `:danger`, `:info`, `:success`, `:warning`. default: `:warning`\n\nFormatting and transform options correspond to the given alert `type`:\n\n- `:alert_danger` for type `:danger`\n- `:alert_info` for type `:info`\n- `:alert_success` for type `:success`\n- `:alert_warning` for type `:warning`","ref":"Cowrie.html#alert/2"},{"type":"function","title":"Examples - Cowrie.alert/2","doc":"iex(2)> alert(\"The answer is 42\", type: :info)\n    ╔═══════════════════════════╗\n    ║ ℹ️  Info:️ The answer is 42 ║\n    ╚═══════════════════════════╝","ref":"Cowrie.html#alert/2-examples"},{"type":"function","title":"Cowrie.br/0","doc":"Prints a line break (an empty line) to STDOUT.\n\nFormatting and transforms options: `:br`","ref":"Cowrie.html#br/0"},{"type":"function","title":"Examples - Cowrie.br/0","doc":"iex> br","ref":"Cowrie.html#br/0-examples"},{"type":"function","title":"Cowrie.colors/0","doc":"Outputs available ANSI colors, useful when you want to choose a color visually.","ref":"Cowrie.html#colors/0"},{"type":"function","title":"Examples - Cowrie.colors/0","doc":"iex> colors","ref":"Cowrie.html#colors/0-examples"},{"type":"function","title":"Cowrie.comment/2","doc":"Prints a comment to STDOUT, i.e. supplemental text regarded as non-essential.\n\nFormatting and transforms options: `:comment`","ref":"Cowrie.html#comment/2"},{"type":"function","title":"Examples - Cowrie.comment/2","doc":"iex> comment(\"Objects are closer than they appear\")\n    Objects are closer than they appear","ref":"Cowrie.html#comment/2-examples"},{"type":"function","title":"Cowrie.dd/2","doc":"Prints a dictionary definition (dd) to STDOUT\n\nFormatting and transforms options: `:dd`","ref":"Cowrie.html#dd/2"},{"type":"function","title":"Cowrie.demo/0","doc":"Prints a demonstration of all output functions for visual inspection, useful when you\nare tweaking your styling.","ref":"Cowrie.html#demo/0"},{"type":"function","title":"Examples - Cowrie.demo/0","doc":"iex> demo\n                                 Cowrie Formatting h1/2\n\n    Common Outputs h2/2)\n\n    This is a line of text line/2\n    This is an informational message info/2\n    This is a warning/2\n    Here comes an hr/2:\n    This is an error/2\n      ────────────────────────────────────────────────────────────────────────\n\n    Alerts h2/2\n\n    ╔════════════════════════════════╗\n    ║ ℹ️  Info:️ This is an info alert ║\n    ╚════════════════════════════════╝\n    # ... etc ...","ref":"Cowrie.html#demo/0-examples"},{"type":"function","title":"Cowrie.dt/2","doc":"Prints a dictionary term (dt) to STDOUT\n\nFormatting and transforms options: `:dt`","ref":"Cowrie.html#dt/2"},{"type":"function","title":"Examples - Cowrie.dt/2","doc":"iex(5)> dt(\"Thonking\", dt: \">>> \" <> IO.ANSI.bright())\n    >>> Thonking","ref":"Cowrie.html#dt/2-examples"},{"type":"function","title":"Cowrie.error/2","doc":"Prints an error message to STDERR.\n\nFormatting and transforms options: `:error`\n\nYour terminal may already provide formatting for messages sent to STDERR; be careful\nabout formatting these messages because you are more likely to have tests that assert\nfor specific error messages being logged, and adding ANSI formatting codes to the output\ncan make it a bit more difficult to verify the exact text.","ref":"Cowrie.html#error/2"},{"type":"function","title":"Cowrie.h1/2","doc":"Prints a primary heading (h1) to STDOUT.\n\nFormatting and transforms options: `:h1`","ref":"Cowrie.html#h1/2"},{"type":"function","title":"Examples - Cowrie.h1/2","doc":"Normally, you would put your pre- and post-transformation functions in your config, but you\ncan pass them as arguments if you really want to:\n\n    iex> h1(\"This is awesome!\", pre_transforms: %{h1: &Cowrie.Transforms.upcase/2})\n\n    THIS IS AWESOME!","ref":"Cowrie.html#h1/2-examples"},{"type":"function","title":"Cowrie.h2/2","doc":"Prints a secondary heading (h2) to STDOUT.\n\nFormatting and transforms options: `:h2`","ref":"Cowrie.html#h2/2"},{"type":"function","title":"Cowrie.hr/1","doc":"Prints a horizontal rule (hr) to STDOUT.\n\nFormatting options:\n\n- `:hr` for the line as a whole\n- `:hr_char` specifies the character(s) to be repeated to form the line.\n- `:hr_padding` number of whitespace columns\n\nTransform key: `:hr`","ref":"Cowrie.html#hr/1"},{"type":"function","title":"Examples - Cowrie.hr/1","doc":"iex> hr(hr_char: \"~\", hr_padding: 0)\n                  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~","ref":"Cowrie.html#hr/1-examples"},{"type":"function","title":"Cowrie.info/2","doc":"Prints informational text to STDOUT.\n\nFormatting and transforms options: `:info`","ref":"Cowrie.html#info/2"},{"type":"function","title":"Cowrie.li/2","doc":"Prints a list item (unordered) to STDOUT.\n\nThis function is useful if don't have a list to pass to `ul/2`.\n\nFormatting option: `:li`; transform options: `:ul_li`.\n`:li_bullet` changes the character(s) used for the list bullet.","ref":"Cowrie.html#li/2"},{"type":"function","title":"Examples - Cowrie.li/2","doc":"iex> li(\"Bullet me\", li_bullet: \"~>\")\n    ~> Bullet me","ref":"Cowrie.html#li/2-examples"},{"type":"function","title":"Cowrie.line/2","doc":"Prints a line of \"unformatted\" text to STDOUT.\n\nFormatting and transforms options: `:line`","ref":"Cowrie.html#line/2"},{"type":"function","title":"Cowrie.ol/2","doc":"Prints an ordered list of items (ul) to STDOUT.\n\n- `:ol_start` the integer used to start the lists. Default: 1\n- `:li` for formatting the individual list items.\n\nPre- and post-transform key: `:ol_li`","ref":"Cowrie.html#ol/2"},{"type":"function","title":"Examples - Cowrie.ol/2","doc":"iex> ol([\"do\", \"re\", \"mi\"])\n    1. do\n    2. re\n    3. mi","ref":"Cowrie.html#ol/2-examples"},{"type":"function","title":"Cowrie.prompt/2","doc":"Prompts the user for input. Input will be consumed until Enter is pressed.\n*Careful:* the returned value will include a newline (`\\n`)!\n\nFormatting and transforms options: `:prompt`","ref":"Cowrie.html#prompt/2"},{"type":"function","title":"Cowrie.secret/2","doc":"The user's input will not be visible to them as they type in the console.\nThis method is useful when asking for sensitive information such as a password.\n\nFormatting and transforms options: `:secret`","ref":"Cowrie.html#secret/2"},{"type":"function","title":"Cowrie.spinner/2","doc":"Displays a spinner animation which offers visual feedback appropriate for long-\nrunning tasks.  Displaying a spinner animation is most appropriate for tasks which\ndo not provide their own console messaging or when you wish to silence the task's\nown messaging.\n\nThe callback function must be a zero-arity anonymous function. The return value\nof the spinner function will the return value of this function.\n\nNote: the task being executed should avoid any use of `IO.puts` (or other functions\nthat write to STDOUT) and instead rely on `Mix.shell().info`; all console messages\nlogged by the callback will be silenced by temporarily setting the `Mix.Shell` to\n`Mix.Shell.Quiet` for the duration of the executed function.","ref":"Cowrie.html#spinner/2"},{"type":"function","title":"Examples - Cowrie.spinner/2","doc":"Using the function capture notation `&`:\n\n    iex> spinner(&Heavy.work/0)\n\nUsing an anonymous function:\n\n    iex> spinner(fn -> Heavy.work() end)\n\nAs used in the demo:\n\n    iex> spinner(fn -> Process.sleep(:timer.seconds(5)) end)\n\nDemonstrating a return value:\n\n    iex> spinner(fn ->\n    ...>   Process.sleep(:timer.seconds(5))\n    ...>   {:ok, \"Task complete!\"}\n    ...> end)\n    {:ok, \"Task complete!\"}\n\nSpecifying a custom spinner module:\n\n    iex> spinner(fn ->\n    ...>   Process.sleep(:timer.seconds(5))\n    ...>   {:ok, \"Task complete!\"}\n    ...> end, spinner_module: Tacocat.Cat)\n    {:ok, \"Task complete!\"}","ref":"Cowrie.html#spinner/2-examples"},{"type":"function","title":"Cowrie.table/3","doc":"Prints a table with the given rows to STDOUT (headers are optional).\n\nThe first argument should be a list of lists, where each internal list represents a row of data.\nThe second argument should be a list of headers -- the length of this list\nshould match the length of the lists passed as rows.\n\nFormatting options:\n- `:th` for header cells\n- `:td` for data cells\n\nTransforms:\n- `:th` for header cells\n- `:td` for data cells","ref":"Cowrie.html#table/3"},{"type":"function","title":"Examples: - Cowrie.table/3","doc":"iex(12)> table([[\"Max\", \"Mao\", \"Brutus\"], [\"Fido\", \"Whiskers\", \"Wilbur\"]], [\"Dogs\", \"Cats\", \"Pigs\"])\n    +------+----------+--------+\n    | Dogs | Cats     | Pigs   |\n    +------+----------+--------+\n    | Max  | Mao      | Brutus |\n    | Fido | Whiskers | Wilbur |\n    +------+----------+--------+","ref":"Cowrie.html#table/3-examples"},{"type":"function","title":"Cowrie.ul/2","doc":"Prints an unordered list of items (ul) to STDOUT.\n\n- `:li_bullet` the character used to denote each list item. Default: `-`\n- `:li` for formatting the individual list items.\n\nTransform key for each list item: `:ul_li`","ref":"Cowrie.html#ul/2"},{"type":"function","title":"Examples - Cowrie.ul/2","doc":"iex(13)> ul([\"Sunlight\", \"Water\", \"Soil\"])\n    - Sunlight\n    - Water\n    - Soil\n\n    iex(14)> ul([\"Sunlight\", \"Water\", \"Soil\"], li_bullet: \">\")\n    > Sunlight\n    > Water\n    > Soil","ref":"Cowrie.html#ul/2-examples"},{"type":"function","title":"Cowrie.warning/2","doc":"Prints a warning to STDOUT.\n\nFormatting and transforms options: `:warning`","ref":"Cowrie.html#warning/2"},{"type":"function","title":"Cowrie.yes?/2","doc":"Prompts the user to continue with a simple `Yes` or `No`.","ref":"Cowrie.html#yes?/2"},{"type":"module","title":"Cowrie.TimerSpinner","doc":"This module implements an animation (a spinner) which includes an HH:MM:SS\ntimer to show elapsed time.\n\nWarning: this spinner does not display properly when the screen becomes too\nnarrow!","ref":"Cowrie.TimerSpinner.html"},{"type":"module","title":"Cowrie.Transforms","doc":"Defines functions that _transform_ (a.k.a. mutate) text. These functions do\nnot print the text and they do not apply ANSI formatting.","ref":"Cowrie.Transforms.html"},{"type":"function","title":"Cowrie.Transforms.alert_danger/2","doc":"Prepends a Danger emoji to the given text.","ref":"Cowrie.Transforms.html#alert_danger/2"},{"type":"function","title":"Cowrie.Transforms.alert_info/2","doc":"Prepends an Info emoji to the given text.","ref":"Cowrie.Transforms.html#alert_info/2"},{"type":"function","title":"Cowrie.Transforms.alert_success/2","doc":"Prepends a Success emoji to the given text.","ref":"Cowrie.Transforms.html#alert_success/2"},{"type":"function","title":"Cowrie.Transforms.alert_warning/2","doc":"Prepends a Warning emoji to the given text.","ref":"Cowrie.Transforms.html#alert_warning/2"},{"type":"function","title":"Cowrie.Transforms.append_newline/2","doc":"Appends a newline to the text.","ref":"Cowrie.Transforms.html#append_newline/2"},{"type":"function","title":"Cowrie.Transforms.box/2","doc":"Draws a box around the given text. The text must be less than one line and\nit should not contain newlines.\n\nAvailable configuration:\n\n`:box_chars` - a map with keys containing for the top(t), top-right(tr),\nright (right), bottom-right (br), bottom (b), bottom-left (bl), left (l),\nand top-left (tl) characters to be used when drawing the box.\n\nDefault:\n      %{\n        t: \"═\",\n        tr: \"╗\",\n        r: \"║\",\n        br: \"╝\",\n        b: \"═\",\n        bl: \"╚\",\n        l: \"║\",\n        tl: \"╔\"\n      }\n\n`:box_padding` - integer representing the number of columns of empty space between\nthe box's left and right borders and the text, default: `1`","ref":"Cowrie.Transforms.html#box/2"},{"type":"function","title":"Cowrie.Transforms.capitalize/2","doc":"A wrapper for `String.capitalize/2`","ref":"Cowrie.Transforms.html#capitalize/2"},{"type":"function","title":"Cowrie.Transforms.center/2","doc":"Centers the given text using the configured column width (:cols)","ref":"Cowrie.Transforms.html#center/2"},{"type":"function","title":"Cowrie.Transforms.downcase/2","doc":"A wrapper for `String.downcase/2`","ref":"Cowrie.Transforms.html#downcase/2"},{"type":"function","title":"Cowrie.Transforms.hr/2","doc":"Creates a horizontal line","ref":"Cowrie.Transforms.html#hr/2"},{"type":"function","title":"Cowrie.Transforms.ol_li/2","doc":"Formats a list item for an ordered list by applying the `:n` character.","ref":"Cowrie.Transforms.html#ol_li/2"},{"type":"function","title":"Cowrie.Transforms.prepend_newline/2","doc":"Prepends a newline to the text.","ref":"Cowrie.Transforms.html#prepend_newline/2"},{"type":"function","title":"Cowrie.Transforms.ul_li/2","doc":"Formats a list item for an unordered list by applying the `:li_bullet` character.","ref":"Cowrie.Transforms.html#ul_li/2"},{"type":"function","title":"Cowrie.Transforms.upcase/2","doc":"A wrapper for `String.upcase/2`","ref":"Cowrie.Transforms.html#upcase/2"},{"type":"extras","title":"Cowrie Overview","doc":"# Cowrie Overview\n\n`Cowrie` helps you print beautiful and consistent Terminal output to the Shell\nof your Elixir apps using functions inspired by familiar HTML tags, e.g.\n\n```elixir\nimport Cowrie\n\nh1(\"This is a Heading\")\nol([\"This is\", \"an ordered\", \"list via ol/2\"])\nwarning(\"Uh oh...\")\n```\n![Cowrie Demo](https://www.udrop.com/plugins/imageviewer/site/show_image.php?idt=31c70a72005f18fecf68c47d6c735ea1&f=9913)\n\nAll formatting is [configurable](config.md), either via your application's configuration file, \nor as arguments to the various functions. Sensible defaults are provided, but check out the [configuration options](config.md).\n\nAll formatting styles rely on `IO.ANSI` formatting options, so you are free to\nresearch and apply your own styles to match your personal preference.","ref":"overview.html"},{"type":"extras","title":"Usage - Cowrie Overview","doc":"Use `Cowrie` functions in your custom `Mix.Task` -- importing `Cowrie` makes its \nfunctions easier to use.\n\n```\ndefmodule Mix.Tasks.MyApp.Example do\n  use Mix.Task\n  import Cowrie\n\n  @shortdoc \"Example mix task using Cowrie\"\n\n\n  def run(opts) do\n    h1(\"My Custom Task\")\n    warning(\"The following issues were found:\")\n    ul([\"Lions\", \"Tigers\", \"Bears\"])\n    spinner(fn -> MyApp.long_task() end)\n  end\nend\n```\n\nReady? Check out the `Cowrie` API.","ref":"overview.html#usage"},{"type":"extras","title":"Configuration","doc":"# Configuration\n\n`Cowrie` is built to be stylable. Instead of a Cascading Style Sheets (CSS), we have configuration details.\n\nMost of the functions will pass their text through the following pipeline:\n\n1. Pre-transformation (where one or more functions modifies the input text)\n2. Formatting (where `IO.ANSI` codes are applied as a prefix to the input text)\n3. Post-format (where `IO.ANSI` reset codes are applied as a suffix to the input text) \n4. Post-transformation (where one or more functions modifies the formatted text)\n\nThe configuration settings have sections corresponding to these steps.","ref":"config.html"},{"type":"extras","title":"Pre-Transformations - Configuration","doc":"Pre-transformations are functions that alter the text _before_ it is formatted. These functions are appropriate for tasks such as capitalizing words or centering the output by padding it with spaces.\n\nPre-transformations are defined inside the `:pre_transforms` configuration option; most functions in `Cowrie` accept a key inside `:pre_transforms` corresponding to their function name.\n\nThese pre-transformations are called _before_ the corresponding formatting function is applied.\n\nThe values here should either be callbacks using the [`&` capture operator](https://hexdocs.pm/elixir/Kernel.SpecialForms.html#&/1) syntax pointing to a function with an arity of 2 (e.g. `&Mod.fun/arity`, OR a list of such callbacks.","ref":"config.html#pre-transformations"},{"type":"extras","title":"Formatting - Configuration","doc":"Most functions in `Cowrie` include a formatting configuration key corresponding to their name.\n\nThe bulk of `Cowrie`'s configuration options expect `IO.ANSI` functions to render ANSI escape sequences. These functions return special text that cause your terminal to format and/or colorize the output that follows.  You can try this out in `iex` -- just concatenate the functions' outputs with the string you wish to format, e.g.\n\n```iex\niex> IO.ANSI.bright() <> IO.ANSI.blue() <> \"Big Blue!\"\n\"\\e[1m\\e[34mBig Blue!\"\niex> Mix.shell().info(IO.ANSI.bright() <> IO.ANSI.blue() <> \"Big Blue!\")\nBig Blue!\n:ok\n```\n\nThe raw return value is a strange-looking string: `\"\\e[1m\\e[34mBig Blue!\"`.  It isn't until you pass that to your `Mix.Shell` that you will actually see the result of this formatting.","ref":"config.html#formatting"},{"type":"extras","title":"Post-Format - Configuration","doc":"If no key is defined inside the `post_format` map, the following ANSI reset codes will be appended to the formatted text:\n```\nIO.ANSI.default_background() <> IO.ANSI.normal() <> IO.ANSI.reset()\n```\n\nEven though the reset codes are not normally visible, there are times when you may not wish them to precisely symmetrical or not there at all.  One case is for error messages (which you may have tests that assert for). Also, error messages should receive some default coloring from Elixir already.  For this reason, the formatting and `post_format` options for the `error/2` are disabled: the post_format option is set to `\"\"`.  Otherwise all error messages would include the ANSI reset `\"\\e[49m\\e[22m\\e[0m\"` appended to them, and that could easily make testing a nightmare. Consider disabling ANSI entirely for your test environment.","ref":"config.html#post-format"},{"type":"extras","title":"Post-Transformation - Configuration","doc":"Post-transformations are functions that alter the text _after_ it has been formatted. These functions can be used for final formatting touches such as adding an extra newline to the formatted text to give it the desired spacing.\n\nPost-transformations are defined inside the `:post_transforms` configuration option; most functions in `Cowrie` accept a key inside `:post_transforms` corresponding to their function name.","ref":"config.html#post-transformation"},{"type":"extras","title":"Other Settings - Configuration","doc":"There are a few other options that exist: mostly these exist so that `Cowrie` functions can dispatch to \nmodules that implement a specific behaviour.  For example the `:spinner_module` option must point to a \nmodule that can properly draw a spinner animation.\n\n```\nconfig :cowrie,\n    # Must implement the `Cowrie.SpinnerBehaviour` behaviour\n    spinner_module: Cowrie.TimerSpinner\n```\n \n---------","ref":"config.html#other-settings"},{"type":"extras","title":"Sample Configuration - Configuration","doc":"Inside your `config/config.exs` (or environment-specific config), you may define any (or none) of the following:\n\n```elixir\nconfig :cowrie,\n  alert_danger: IO.ANSI.red(),\n  alert_info: IO.ANSI.blue(),\n  alert_success: IO.ANSI.green(),\n  alert_warning: IO.ANSI.yellow(),\n  box_chars: %{\n    t: \"═\",\n    tr: \"╗\",\n    r: \"║\",\n    br: \"╝\",\n    b: \"═\",\n    bl: \"╚\",\n    l: \"║\",\n    tl: \"╔\"\n  },\n  box_padding: 1,\n  br: \"\",\n  cols: 80,\n  comment: IO.ANSI.color(246),\n  error: \"\",\n  dt: IO.ANSI.blue(),\n  dd: \"    : \" <> IO.ANSI.color(246),\n  h1: IO.ANSI.bright() <> IO.ANSI.white_background() <> IO.ANSI.black(),\n  h1_transform: &Cowrie.Transforms.upcase/2,\n  h2: IO.ANSI.bright(),\n  info: IO.ANSI.blue(),\n  hr: IO.ANSI.color(236),\n  hr_char: \"─\",\n  hr_padding: 4,\n  li: \"\",\n  li_bullet: \"-\",\n  line: \"\",\n  ol_start: 1,\n  prompt: \"\",\n  secret: \"\",\n  th: IO.ANSI.bright(),\n  td: \"\",\n  warning: IO.ANSI.red(),\n  yes?: \"\",\n  # The post_format map can define custom formatting resets.\n    post_format: %{\n      error: \"\"\n    },\n  # The pre_transforms map can define callbacks to functions that modify the text\n  # before formatting it.\n  pre_transforms: %{\n    alert_danger: &Cowrie.Transforms.alert_danger/2,\n    alert_info: &Cowrie.Transforms.alert_info/2,\n    alert_success: &Cowrie.Transforms.alert_success/2,\n    alert_warning: &Cowrie.Transforms.alert_warning/2,\n    h1: &Cowrie.Transforms.center/2,\n    hr: &Cowrie.Transforms.hr/2,\n    ol_li: &Cowrie.Transforms.ol_li/2,\n    ul_li: &Cowrie.Transforms.ul_li/2\n  },\n  post_transforms: %{\n    h1: [&Cowrie.Transforms.prepend_newline/2, &Cowrie.Transforms.append_newline/2],\n    h2: &Cowrie.Transforms.append_newline/2,\n    hr: &Cowrie.Transforms.append_newline/2\n  },\n  # Must implement the `Cowrie.SpinnerBehaviour` behaviour\n  spinner_module: Cowrie.TimerSpinner\n```\n\nRemember to try out `Cowrie.demo/0` to visually inspect the results of your styling. You can also use `Cowrie.colors/0` to display a list of all available color swatches.","ref":"config.html#sample-configuration"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}